@@ -8,9 +8,9 @@ use Log::ger;
 use App::orgadb::Common;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2025-01-19'; # DATE
+our $DATE = '2025-02-13'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 our %SPEC;
 
@@ -126,7 +126,10 @@ sub _select_single {
         $expr .= (length $expr ? " " : "") . 'Headline[level=2]';
         if (defined $args{entry}) {
             $expr .= '[title.as_string';
-            if (ref $args{entry} eq 'Regexp') {
+            if ($args{entry_match_mode} =~ /exact/) {
+                $re_entry = quotemeta($args{entry});
+                $re_entry = $args{entry_match_mode} =~ /-ci/ ? qr/^$re_entry$/i : qr/^$re_entry$/;
+            } elsif (ref $args{entry} eq 'Regexp') {
                 $re_entry = $args{entry};
             } else {
                 $re_entry = quotemeta($args{entry});
@@ -207,7 +210,10 @@ sub _select_single {
                         $expr_field .= ($expr_field ? ' > List > ' : 'Headline[level=2] > List > ');
                         $expr_field .= 'ListItem[desc_term.text';
                         my $re_field;
-                        if (ref $field_term eq 'Regexp') {
+                        if ($args{field_match_mode} =~ /exact/) {
+                            $re_field = quotemeta($field_term);
+                            $re_field = $args{field_match_mode} =~ /-ci/ ? qr/^$re_field$/i : qr/^$re_field$/;
+                        } elsif (ref $field_term eq 'Regexp') {
                             $re_field = $field_term;
                         } else {
                             $re_field = quotemeta($field_term);
@@ -519,7 +525,7 @@ App::orgadb - An opinionated Org addressbook toolset
 
 =head1 VERSION
 
-This document describes version 0.018 of App::orgadb (from Perl distribution App-orgadb), released on 2025-01-19.
+This document describes version 0.019 of App::orgadb (from Perl distribution App-orgadb), released on 2025-02-13.
 
 =head1 SYNOPSIS
 
@@ -589,6 +595,46 @@ version of C<--detail>, as in I<ls> Unix command.
 
 Find entry by string or regex search against its title.
 
+=item * B<entry_match_mode> => I<str> (default: "default")
+
+How entry should be matched.
+
+The default matching mode is as follow:
+
+ str       Substring matching
+ /re/      Regular expression matching
+
+If matching mode is set to C<exact>, then matching will be done by string
+equality test. This mode is basically a shorter alternative to having to
+specify:
+
+ /^\Qre\E$/
+
+Matching mode C<exact-ci> is like C<exact> except case-insensitive. It is
+equivalent to:
+
+ /^\Qre\E$/i
+
+=item * B<field_match_mode> => I<str> (default: "default")
+
+How entry should be matched.
+
+The default matching mode is as follow:
+
+ str       Substring matching
+ /re/      Regular expression matching
+
+If matching mode is set to C<exact>, then matching will be done by string
+equality test. This mode is basically a shorter alternative to having to
+specify:
+
+ /^\Qre\E$/
+
+Matching mode C<exact-ci> is like C<exact> except case-insensitive. It is
+equivalent to:
+
+ /^\Qre\E$/i
+
 =item * B<field_value_formatter_rules> => I<array[hash]>
 
 Specify field value formatters to use when conditions are met, specified as an
