@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2025-01-19'; # DATE
+our $DATE = '2025-02-13'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 sub _heading_from_line {
     my $heading = shift;
@@ -286,11 +286,65 @@ our %argspecopt1_field = (
 our %argspecs_select = (
 
     %argspecopt0_entry,
+    entry_match_mode => {
+        summary => 'How entry should be matched',
+        schema => ['str*', in=>['default', 'exact', 'exact-ci']], # TODO: fuzzy matching
+        default => 'default',
+        description => <<'MARKDOWN',
+
+The default matching mode is as follow:
+
+    str       Substring matching
+    /re/      Regular expression matching
+
+If matching mode is set to `exact`, then matching will be done by string
+equality test. This mode is basically a shorter alternative to having to
+specify:
+
+    /^\Qre\E$/
+
+Matching mode `exact-ci` is like `exact` except case-insensitive. It is
+equivalent to:
+
+    /^\Qre\E$/i
+
+MARKDOWN
+        cmdline_aliases => {
+            x => { is_flag=>1, summary=>'Turn on exact entry matching (shortcut for `--entry-match-mode=exact`)', code => sub { $_[0]{entry_match_mode} = 'exact' } },
+        },
+    },
 
     %argspecopt_category,
 
     %argspecopt1_field,
     %argspecopt_filter_entry_by_fields,
+    field_match_mode => {
+        summary => 'How entry should be matched',
+        schema => ['str*', in=>['default', 'exact', 'exact-ci']], # TODO: fuzzy matching
+        default => 'default',
+        description => <<'MARKDOWN',
+
+The default matching mode is as follow:
+
+    str       Substring matching
+    /re/      Regular expression matching
+
+If matching mode is set to `exact`, then matching will be done by string
+equality test. This mode is basically a shorter alternative to having to
+specify:
+
+    /^\Qre\E$/
+
+Matching mode `exact-ci` is like `exact` except case-insensitive. It is
+equivalent to:
+
+    /^\Qre\E$/i
+
+MARKDOWN
+        cmdline_aliases => {
+            X => { is_flag=>1, summary=>'Turn on exact entry matching (shortcut for `--field-match-mode=exact`)', code => sub { $_[0]{field_match_mode} = 'exact' } },
+        },
+    },
 
     hide_category => {
         summary => 'Do not show category',
@@ -496,7 +550,7 @@ App::orgadb::Common
 
 =head1 VERSION
 
-This document describes version 0.018 of App::orgadb::Common (from Perl distribution App-orgadb), released on 2025-01-19.
+This document describes version 0.019 of App::orgadb::Common (from Perl distribution App-orgadb), released on 2025-02-13.
 
 =head1 HOMEPAGE
 
