@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2025-01-19'; # DATE
+our $DATE = '2025-02-13'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 use App::orgadb::Common;
 
@@ -127,7 +127,7 @@ App::orgadb::Select::Shell::Commands - orgadb-sel shell commands
 
 =head1 VERSION
 
-This document describes version 0.018 of App::orgadb::Select::Shell::Commands (from Perl distribution App-orgadb), released on 2025-01-19.
+This document describes version 0.019 of App::orgadb::Select::Shell::Commands (from Perl distribution App-orgadb), released on 2025-02-13.
 
 =for Pod::Coverage .+
 
@@ -221,6 +221,46 @@ version of C<--detail>, as in I<ls> Unix command.
 
 Find entry by string or regex search against its title.
 
+=item * B<entry_match_mode> => I<str> (default: "default")
+
+How entry should be matched.
+
+The default matching mode is as follow:
+
+ str       Substring matching
+ /re/      Regular expression matching
+
+If matching mode is set to C<exact>, then matching will be done by string
+equality test. This mode is basically a shorter alternative to having to
+specify:
+
+ /^\Qre\E$/
+
+Matching mode C<exact-ci> is like C<exact> except case-insensitive. It is
+equivalent to:
+
+ /^\Qre\E$/i
+
+=item * B<field_match_mode> => I<str> (default: "default")
+
+How entry should be matched.
+
+The default matching mode is as follow:
+
+ str       Substring matching
+ /re/      Regular expression matching
+
+If matching mode is set to C<exact>, then matching will be done by string
+equality test. This mode is basically a shorter alternative to having to
+specify:
+
+ /^\Qre\E$/
+
+Matching mode C<exact-ci> is like C<exact> except case-insensitive. It is
+equivalent to:
+
+ /^\Qre\E$/i
+
 =item * B<field_value_formatter_rules> => I<array[hash]>
 
 Specify field value formatters to use when conditions are met, specified as an
